@@ -35,7 +35,19 @@ class AsyncConnectionPool(BasePool[AsyncConnection[Any]]):
         connection_class: Type[AsyncConnection[Any]] = AsyncConnection,
         configure: Optional[Callable[[AsyncConnection[Any]], Awaitable[None]]] = None,
         reset: Optional[Callable[[AsyncConnection[Any]], Awaitable[None]]] = None,
-        **kwargs: Any,
+        kwargs: Optional[Dict[str, Any]] = None,
+        min_size: int = 4,
+        max_size: Optional[int] = None,
+        name: Optional[str] = None,
+        timeout: float = 30.0,
+        max_waiting: int = 0,
+        max_lifetime: float = 60 * 60.0,
+        max_idle: float = 10 * 60.0,
+        reconnect_timeout: float = 5 * 60.0,
+        reconnect_failed: Optional[
+            Callable[[BasePool[AsyncConnection[Any]]], None]
+        ] = None,
+        num_workers: int = 3,
     ):
         self.connection_class = connection_class
         self._configure = configure
@@ -54,7 +66,21 @@ class AsyncConnectionPool(BasePool[AsyncConnection[Any]]):
         self._sched_runner: Optional[Task[None]] = None
         self._workers: List[Task[None]] = []
 
-        super().__init__(conninfo, **kwargs)
+        super().__init__(
+            conninfo,
+            kwargs=kwargs,
+            min_size=min_size,
+            max_size=max_size,
+            open=open,
+            name=name,
+            timeout=timeout,
+            max_waiting=max_waiting,
+            max_lifetime=max_lifetime,
+            max_idle=max_idle,
+            reconnect_timeout=reconnect_timeout,
+            reconnect_failed=reconnect_failed,
+            num_workers=num_workers,
+        )
 
         if open:
             self._open()
@@ -337,6 +363,11 @@ class AsyncConnectionPool(BasePool[AsyncConnection[Any]]):
             conns = list(self._pool)
             self._pool.clear()
 
+            # Give a chance to the pool to grow if it has no connection.
+            # In case there are enough connection, or the pool is already
+            # growing, this is a no-op.
+            self._maybe_grow_pool()
+
         while conns:
             conn = conns.pop()
             try:
